ServerEvents.recipes(event => {
    /*
            Build grist
        none -> basic: create a pulverizer, grind sand into grist -> make basic tier of machines and tools (pulverizer, redstone furnace, alloy smelter, )
            basic grist only comes from pulverizing sand into grist, or you get 4x from pulverizing improved grist
            pulverizer would require a tin gear which requires four tin ingots plus either one build grist or diamond in the center
        basic -> improved: create cobble to gravel to sand to grist generator (with basic power + basic automation) -> overcome the cost of newer machines, world building gadgets, automate food production
            full machine would require some pipes automation (intelligent), power (energetic), and food to harvest the materials (agricultural)
            all machines required would need gears made from one build grist in the center
                machines: pulverizier, sequential crafter...?
            after you get improved, you can make the gear die and make gears without grist
                3x improved grist can also come from alloy smelting cobblestone, gravel, sand in the right quantities
    */

    /*
    2x Basic build grist comes from smelting build grist with primordeal
    Your first build grist comes from smelting refined aggregate
    refined aggregate comes from pulverizing reduced aggregate, which comes from coarse aggregate
    coarse aggregate comes from combining sand, clay, gravel, primordeal with an ore hammer.

    Instead of an ore hammer, you can use a heated mixer with create
    */
    event.recipes.thermal.smelter(
        'kubejs:grist_build_basic_block',
        ['#kubejs:grist/build/basic', 'kubejs:grist_primordeal_basic_block', 'minecrtaft:cobblestone']
    );
    event.custom({
        type: 'create:mixing',
        ingredients: [
            '#kubejs:grist/build/basic',
            'minecraft:cobblestone',
            'kubejs:grist_primordeal_basic_block',
        ],
        heatRequirement: "heated",
        results: [
            'kubejs:grist_build_basic_block'
        ]
    });
    event.smelting('16x kubejs:grist_build_basic', 'kubejs:refined_grist_aggregate');
    event.custom({
        type: 'create:mixing',
        ingredients: [
            '3x #forge:sand',
            'minecraft:clay_ball',
            '3x #forge:gravel',
            'kubejs:grist_primordeal_basic_block'
        ],
        heatRequirement: "heated",
        results: [
            'kubejs:coarse_grist_aggregate'
        ]
    });
    event.custom({
        type: 'create:mixing',
        ingredients: [
            'minecraft:granite',
            'kubejs:grist_primordeal_basic',
            '6x kubejs:coarse_grist_aggregate'
        ],
        heatRequirement: "heated",
        results: [
            'kubejs:reduced_grist_aggregate'
        ]
    });
    event.custom(
        {
            type: 'create:mixing',
            ingredients: [
                'kubejs:grist_primordeal_basic',
                '5x kubejs:reduced_grist_aggregate'
            ],
            heatRequirement: "heated",
            results: [
                'kubejs:refined_grist_aggregate'
            ]
        }
    );

    /*
    improved grist comes from crystalizing clay + improved + primordeal liquid
    your first improved comes from crystalizing 32 reinforced grist ingots with improved primordeal liquid
    grist ingots come from 9 grist nuggets in a servo press
    reinforced grist nuggets come from grist blend in a centrifugal separator
    grist blend comes from basic + improved primordeal block + sulfur in induction smelter
    */

    // Improved grist starts by smelting together build grist, primordeal improved grist, and sulfur to create reinforced grist blend
    event.recipes.thermal.smelter(
        'kubejs:reinforced_grist_blend',
        ['32x #kubejs:grist/build/basic', '8x kubejs:grist_primordeal_improved_block', '2x #forge:dusts/sulfur']
    );

    // The grist blend is then centrifuged to extract nuggets
    /*event.recipes.thermal.centrifuge([
        'kubejs:reinforced_grist_nugget',
        Fluid.of('kubejs:grist_build_basic_fluid', 125)
    ], 'kubejs:reinforced_grist_blend');*/

    event.custom({
        type: 'thermal:centrifuge',
        ingredients: [
            { item: 'kubejs:reinforced_grist_blend', count: 3 }
        ],
        results: [
            { fluid: 'kubejs:grist_build_basic_fluid', amount: 225 },
            { item: 'kubejs:grist_essence', chance: 0.2 },
            { item: 'kubejs:reinforced_grist_nugget' },
        ]
    });

    // 9 nuggets combine only in a press to create a reinforced grist ingot
    event.custom({
        type: "thermal:press",
        ingredients: [
            { item: 'kubejs:reinforced_grist_nugget', count: 9 },
            { item: "thermal:press_packing_3x3_die" }
        ],
        result: [{item: 'kubejs:reinforced_grist_ingot'}]
    });

    // Finally, you crystallize a pile of ingots with improved primordeal fluid.
    event.recipes.thermal.crystallizer(
        '2x kubejs:grist_build_improved_block',
        ['32x kubejs:reinforced_grist_ingot', Fluid.of('kubejs:grist_primordeal_improved_fluid', 8000)]
    );

    // After that, you simply re-crystalize it along with a little bit of clay
    event.recipes.thermal.crystallizer(
        'kubejs:grist_build_improved_block',
        ['4x minecraft:clay', '#kubejs:grist/build/improved', Fluid.of('kubejs:grist_primordeal_improved_fluid', 4500)]
    );

    /*event.custom({
        type: "thermal:centrifuge",
        ingredients: [
            { item: 'kubejs:reinforced_grist_blend' },
        ],
        result: [{item: 'kubejs:build_grist_basic'}, {item: 'kubejs:reinforced_grist_nugget', chance: 0.3}]
    });*/

    /*
    improved -> radiant: process ores with power generation, new machines, and tool enchants into smelting up grist alloys -> near creative mode world shaping tools, crafting any block
            three grades of grist alloy ingots: tempered, perfect, and flawed
            radiant grist requires energizing a block of tempered alloy

            block of tempered alloy comes from 9 tempered ingots
            tempered ingot comes from 9 tempered nuggets + grist paste in a smelter
            tempered nuggets come from centrifuing a filled crucible
            filled crucibles come from chilling a hot filled crucible
            hot filled crucibles come from energizing tempered nuggets with 1x lumium, 1x signalum, 1x improved build block, 1x crucible

            perfect alloy comes from smelting perfect alloy nuggets with intelligent catalysts + advanced powder power powder (gemium?)
            perfect alloy nugget comes from solidifying 1000mb of liquid alloy in blast chiller with ingot mold
            100mb liquid alloy comes from melting one flawed ingot

            flawed ingots come from energizing 9 flawed nuggets with tremendous power
            flawed nuggets come from ars enchanting with 8x advanced powders around 1x improved build
    */
});